@@ -15,7 +15,7 @@ int linterr(char *reason, char *line, int number) {
 int main() {
 	int fd;
 	int vend, dev, subvend, subdev;
-	char module[128], desc[256], desc2[256], line[512];
+	char module[128], desc2[256], line[512];
 	FILE *foo;
 	int linenum = 0, ret;
 	struct stat sbuf;
@@ -29,11 +29,11 @@ int main() {
 			linterr("bad format", line, linenum);
 			continue;
 		}
-		if ((ret = sscanf(line,"%x\t%x\t\"%[^\"]\"\t\"%[^\"]\"",
-			    &vend,&dev,&module,&desc)) != 4) {
-			ret = sscanf(line,"%x\t%x\t%x\t%x\t\"%[^\"]\"\t\"%[^\"]\"",
-			    &vend,&dev,&subvend,&subdev,&module,&desc);
-			if (ret != 6) {
+		if ((ret = sscanf(line,"%x\t%x\t\"%[^\"]\"",
+			    &vend,&dev,&module)) != 3) {
+			ret = sscanf(line,"%x\t%x\t%x\t%x\t\"%[^\"]\"",
+			    &vend,&dev,&subvend,&subdev,&module);
+			if (ret != 5) {
 				linterr("bad format",line,linenum);
 				continue;
 			}
@@ -60,8 +60,6 @@ int main() {
 				continue;
 			}
 		}
-		if  (!strchr(desc,'|'))
-			linterr("no '|' in description",line,linenum);
 	}
 	return errors;
 }
